%ifarch %{java_arches}
%global JAVA 1
%endif

Summary:        Real-time Midi I/O Library
Name:           portmidi
Version:        217
Release:    1%{?dist}
License:        MIT
URL:            http://portmedia.sourceforge.net/
Source0:        http://downloads.sourceforge.net/portmedia/%{name}-src-%{version}.zip
Source1:        pmdefaults.desktop
Patch0:         portmidi-cmake.patch
Patch1:         portmidi-no_date_footer.patch
Patch2:         portmidi-217-format-security.patch
Patch3:         portmidi-no.c++.patch
Patch4:         portmidi-cyrex-0.21.patch
Patch5:         portmidi-c99.patch
Patch100:       portmidi-no.java.patch
BuildRequires: make
BuildRequires:  alsa-lib-devel
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  python3-devel
BuildRequires:  python3-Cython
BuildRequires:  doxygen
BuildRequires:  tex(latex)
BuildRequires:  gcc
%if 0%{?JAVA}
BuildRequires:  java-devel >= 1.7
BuildRequires:  javapackages-tools
%endif

%description
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the PortMidi
libraries.

%package devel
Summary:        Headers for developing programs that will use %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the header files
and the documentation of PortMidi libraries.

%package -n python3-%{name}
Summary:        Python 3 wrapper for %{name}
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{name}
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains the python
bindings of PortMidi libraries. It can send and receive MIDI data in
real-time from Python 3.

%package tools
Summary:          Tools to configure and use %{name}
Requires:         hicolor-icon-theme
Requires:         java >= 1.7
Requires:         %{name} = %{version}-%{release}

%description tools
PortMedia is a set of simple clean APIs and cross-platform library
implementations for music and other media. PortMidi sub-project provides a
real-time MIDI input/output library. This package contains
%{?JAVA:the PortMidi configuration utility "pmdefaults" and 
}some test applications.

%prep
%autosetup -n %{name} -N
%autopatch -p 1 -M 99
%if ! 0%{?JAVA}
%autopatch -p 1 -m 100
%endif


rm -f pm_python/pyportmidi/_pyportmidi.c

rm -f pm_python/setup.py

rm -f portmidi_cdt.zip */*.exe */*/*.exe

find . -name "*.c" -exec chmod -x {} \;
find . -name "*.h" -exec chmod -x {} \;
for i in *.txt */*.txt */*/*.txt ; do
   chmod -x $i
   sed 's|\r||' $i > $i.tmp
   touch -r $i $i.tmp
   mv -f $i.tmp $i
done

%if 0%{?JAVA}
sed -i 's|loadLibrary.*|load("%{_libdir}/%{name}/libpmjni.so");|' \
   pm_java/jportmidi/JPortMidiApi.java

sed -i -e 's|^java|#!/bin/sh\njava \\\
   -Djava.library.path=%{_libdir}/%{name}/|' \
   -e 's|/usr/share/java/|%{_libdir}/%{name}/|' \
   pm_java/pmdefaults/pmdefaults

sed -i -e 's|/usr/share/java|%{_javadir}|' \
   pm_java/CMakeLists.txt
%endif

%build
export JAVA_HOME=%{java_home}
%cmake -DCMAKE_SKIP_BUILD_RPATH=1 -DCMAKE_CACHEFILE_DIR=%{_builddir}/%{name}/build -DVERSION=%{version} -B.
make %{?_smp_flags}

doxygen

pushd pm_python/pyportmidi
   cython -2 _pyportmidi.pyx
   gcc %{optflags} -pthread -fPIC -c -o _pyportmidi.o -I../../pm_common \
       -I../../porttime $(python3-config --includes) _pyportmidi.c
   gcc -shared -o _pyportmidi.so _pyportmidi.o -lportmidi $(python3-config --libs) \
       -L../../build/Release
popd

%install
%make_install

install -d %{buildroot}%{_libdir}/%{name}
for app in latency midiclock midithread midithru mm qtest sysex test; do
   install -m 0755 build/Release/$app %{buildroot}%{_libdir}/%{name}/
done

%if 0%{?JAVA}
mv %{buildroot}%{_libdir}/libpmjni.so \
   %{buildroot}%{_libdir}/%{name}/
mv %{buildroot}%{_javadir}/pmdefaults.jar \
   %{buildroot}%{_libdir}/%{name}/

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/
install -pm 644 pm_java/pmdefaults/pmdefaults-icon.png \
   %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/

mkdir -p %{buildroot}%{_datadir}/applications/
desktop-file-install \
   --dir=%{buildroot}%{_datadir}/applications \
   %{SOURCE1}
%endif

install -pm 644 pm_common/pmutil.h %{buildroot}%{_includedir}/

mkdir -p %{buildroot}%{python3_sitearch}/pyportmidi
pushd pm_python/pyportmidi
   install -pm 755 _pyportmidi.so %{buildroot}%{python3_sitearch}/pyportmidi/
   install -pm 644 *.py %{buildroot}%{python3_sitearch}/pyportmidi/
popd

%{?filter_setup:
%filter_provides_in %{python3_sitearch}/.*\.so$
%filter_setup
}

rm -f %{buildroot}%{_libdir}/libportmidi_s.so

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%doc CHANGELOG.txt
%license license.txt
%{_libdir}/lib*.so.*

%files tools
%doc pm_java/pmdefaults/README.txt pm_cl/*
%{_libdir}/%{name}/
%if 0%{?JAVA}
%{_bindir}/pmdefaults
%{_datadir}/icons/hicolor/128x128/apps/pmdefaults-icon.png
%{_datadir}/applications/pmdefaults.desktop
%endif

%files -n python3-%{name}
%{python3_sitearch}/pyportmidi/

%files devel
%doc README.txt
%doc html
%{_includedir}/*
%{_libdir}/lib*.so

%changelog
* Wed Jul 17 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 217-1
- initial build
